@@ -14,7 +14,7 @@ if os.name == "nt":
     temp = pathlib.PosixPath
     pathlib.PosixPath = pathlib.WindowsPath
 
-def language_to_iso(self, lang) -> str:
+def language_to_iso(lang) -> str:
     """
 
     Returns: language of the borrowing as 2 letter iso code (or other)
